local ui = {}
local vars = dofile('vars.lua')

local ENABLE_COLORS={OFF='\127707070', ON='\127ffffff'}

--Begin UI --

local function get_volume(value)
	local vol = tonumber(value)
	
	if not vol then vol = 1
	elseif vol >=0 and vol <= 1 then
		--no conversion necessary
	elseif vol > 1 and vol <= 100 then
		vol = vol/100
	else vol = 1 end
	
	return vol
end

ui.element = {}
local sorted_alerts = {}
for id,v in ipairs(vars.alerts) do
	local enable = v.enable and "ON" or "OFF"
	
	ui.element[id] = {}
	ui.element[id].label = iup.label{title="\127ffffff"..v.title.."\127o", expand="Horizontal"}
	ui.element[id].option = v.option_title~=nil and iup.stationtoggle{title=v.option_title, value=v.option_enable and "ON" or "OFF", active=enable} or iup.fill{}
	ui.element[id].data = v.data~=nil and v.data~='' and iup.text{value=v.data, size="80x", active=enable} or iup.fill{} --TODO
	ui.element[id].popup = iup.list{dropdown="YES", active=enable} --TODO
	--ui.element[id].wav = iup.stationtoggle{title="wav", value=v.wav, active=enable} --TODO
	ui.element[id].vol_label = iup.label{title="\127ffffffvolume\127o"}
	ui.element[id].volume = iup.text{value=v.vol or '100', size="40x", active=enable}
	ui.element[id].button = iup.stationbutton{
		title="Test",
		--active=enable, --TODO
		action=function()
			gksound.GKPlaySound(vars.sound_name[tonumber(ui.element[id].popup.value)], get_volume(ui.element[id].volume.value)) --TODO:fix sound name
		end
	}
	ui.element[id].checkbox = iup.stationtoggle{
		title="",
		value=enable,
		action=function(self)
			local active = self.value
			
			if iup.GetType(ui.element[id].option)~='fill' then ui.element[id].option.active = active end
			if iup.GetType(ui.element[id].data)~='fill' then ui.element[id].data.active = active end
			ui.element[id].popup.active = active
			--ui.element[id].wav.active = active
			ui.element[id].volume.active = active
			ui.element[id].button.active = active
			
			ui.element[id].label.title = ENABLE_COLORS[active]..filter_colorcodes(ui.element[id].label.title)
			--ui.element[id].popup.title = ENABLE_COLORS[active]..filter_colorcodes(ui.element[id].popup.title)
			
			iup.Refresh(iup.GetDialog(self))
		end,
	}
	
	--populate list of sounds
	for n=1,vars.NUM_SOUNDS_MAX do
		iup.SetAttribute(ui.element[id].popup,n,'\127ffffffsound'..n..(v.wav and ".wav" or ".ogg"))
	end
	ui.element[id].popup.value = v.sound
	
	--create hbox with parameters for each alert
	ui.element[id].box = iup.hbox{
		ui.element[id].checkbox,
		ui.element[id].label,
		ui.element[id].option,
		ui.element[id].data,
		ui.element[id].popup,
		--ui.element[id].wav, --TODO
		ui.element[id].vol_label,
		ui.element[id].volume,
		ui.element[id].button,
		gap=4,
		rank=v.rank, --non-standard attribute
	}
	
	table.insert(sorted_alerts, ui.element[id].box)
	
	--iup.Append(frame, ui.element[id].box)
end
table.sort(sorted_alerts, function(a,b) return tonumber(a.rank)<tonumber(b.rank) end)

local function ShowHelp()
	StationHelpDialog:Open(
[[Use this window to set all settings for Sound Alert Suite that are saved to the config file. Each row in the dialog corresponds to an action or event in the game that triggers a sound to be played by the plug-in.

*The checkbox on the far left enables sound playback for the given event when checked.
*Additional checkboxes and data fields may appear right of the event description which can be used to set additional parameters relevant to that event.
*The sound to play is chosen from the pop-up box. You can replace the sound files with your own if you choose. Valid file names are "sound1.ogg" to "sound12.ogg", and the sound files should reside in the /plugins/SoundAlertSuite/sounds/ directory.
*The Test button on the far right plays the sound selected in the pop-up so you can hear what it sounds like.

Supported events:
1) Chat to non-active channel -- Plays a sound when someone chats to the channel specified in the data field while you are subscribed to that channel and it is not your active channel.
	Additional parameter: channelid of the channel you want to monitor
2) Chat to active channel -- Plays a sound when someone chats to the specified channel while it is active. Activate both this event and the previous to play a sound regardless of whether the channel is active or not.
	Additional parameter: channelid of the channel you want to monitor
3) Received private message -- Plays a sound when you receive a private message (incluedes PMs from yourself and NPCs)
4) Buddy entered the game -- Plays a sound when one of your buddies logs in
5) Buddy left the game -- Plays a sound when one of your buddies logs out
6) Received buddy request -- Plays a sound both when you send/receive a buddy request and when that request is accepted
7) Received buddy note -- Plays a sound when you have a buddy note when you log in
8) Received credits from player -- Plays a sound when someone sends you credits with the givemoney command (also works when money is sent from NPCs)
9) Enter NFZ -- Plays sound when you enter the No-Fire Zone
10) Leave NFZ -- Plays sound when you leave the No-Fire Zone
11) Mission Updated -- Plays a sound when your mission is updated ('M' icon appears on your HUD)]])
end

local button_help = iup.stationbutton{title="Help", hotkey=iup.K_h, action=ShowHelp}
--iup.hbox{iup.stationbutton{title="Help", hotkey=iup.K_h, action=function() OpenHelp() end}, iup.fill{}, closeb, cancelb}
local button_ok = iup.stationbutton{title="Close"}
--local button_cancel = iup.stationbutton{title="Cancel"}



local frame = iup.vbox{
	iup.hbox{iup.fill{}, iup.label{title="Sound Alert Suite Options",font=Font.H3}, iup.fill{}},
	iup.hbox{iup.fill{}, iup.label{title="Version "..soundalertsuite.version}}, --TODO: remove global use
	alignment="ALEFT",
	unpack(sorted_alerts),
	--iup.label{title=""},
	--iup.hbox{button_help, iup.fill{}, button_ok},
}

iup.Append(frame, iup.label{title=""})
iup.Append(frame, iup.hbox{button_help, iup.fill{}, button_ok})

-- Create Dialog --

ui.dialog = iup.dialog{
	iup.vbox{
		iup.fill{},
		iup.hbox{
			iup.fill{},
			iup.pdarootframe{
			--iup.stationsubframe{
				frame,
				expand="NO",
				gap=8,
			},
			iup.fill{},
		},
		iup.fill{},
	},
	BGCOLOR = "0 0 0 160 *",
	FULLSCREEN="YES",
	RESIZE="NO",
	BORDER="NO",
	MENUBOX="YES",
	TOPMOST="YES",
	DEFAULTESC=button_ok,
	DEFAULTENTER=button_ok
}
ui.dialog:map()

-- Display Dialog --

function ui:Show()
	if not ui.dialog then ui:Init() end
	
	--TODO: reset controls based on vars settings

	ShowDialog(ui.dialog,iup.CENTER,iup.CENTER)
	iup.Refresh(ui.dialog)
end

function ui:Hide()
	for id,v in ipairs(vars.alerts) do
		local old_enable = v.enable
		v.enable = ui.element[id].checkbox.value=="ON" and true or false
		
		--Register/Unregister events if enabled/disabled --TODO:Don't use global soundalertsuite
		if old_enable ~= v.enable then
			for _,event_name in ipairs(v.events) do
				if v.enable then
					if not soundalertsuite.events_index[event_name] then
						RegisterEvent(soundalertsuite, event_name)
						soundalertsuite.events_index[event_name] = {}
					end
					table.insert(soundalertsuite.events_index[event_name], id)
				else
					for n,val in ipairs(soundalertsuite.events_index[event_name]) do
						if val==id then table.remove(soundalertsuite.events_index[event_name], n) end
					end
					
					if #soundalertsuite.events_index[event_name]==0 then
						soundalertsuite.events_index[event_name] = nil
						UnregisterEvent(soundalertsuite, event_name)
					end
				end
			end
		end
		
		v.sound = tonumber(ui.element[id].popup.value)
		v.data = v.data and ui.element[id].data.value
		v.option_enable = v.option_enable~=nil and ui.element[id].option.value=="ON"
		v.vol = get_volume(tonumber(ui.element[id].volume.value))
	end
	
	vars.WriteConfig()
	HideDialog(ui.dialog)
end

function button_ok.action() ui:Hide() end

return ui,vars