local vars = {}
vars.vol_master = tonumber(gkini.ReadString("SAS", "master_volume", '1.0'))
vars.NUM_SOUNDS_MAX = 14

--TODO: Choco function for int2bool
local function int2bool(int)
	if type(int) == 'number' then
		return int==1 and true or false
	elseif type(int) == 'string' then
		return tonumber(int)==1 and true or false
	else return nil end
end

vars.saved_keys = {enable='boolean',sound='number',data='string',option_enable='boolean',vol='number'} --settings to save to config
vars.defaults = {enable=true,sound='1',data='',option_enable=nil,vol=vars.vol_master} --default values to use for config keys
vars.conv_keys = {boolean=int2bool,number=tonumber,string=tostring} --function to use to convert config data

vars.sound_name = {}
local sounds = {}
for i=1,vars.NUM_SOUNDS_MAX do
	vars.sound_name[i] = "sound"..i..".ogg"
	--vars.sound_name[-1] = "sound"..i..".wav" --TODO
	
	sounds[i] = gksound.GKLoadSound{soundname=vars.sound_name[i],filename="plugins/SoundAlertSuite/sounds/"..vars.sound_name[i]}
end


--Do not change the order of these items -- It corresponds to the same order that settings are saved to the config file
--Rank value determines sort order in GUI (lowest first)
vars.alerts = {
	{events={"CHAT_MSG_CHANNEL","CHAT_MSG_CHANNEL_EMOTE"},rank=1,title='Chat to non-active channel',data="4357",func='isChatAlert',sound=1},
	{events={"CHAT_MSG_CHANNEL_ACTIVE","CHAT_MSG_CHANNEL_EMOTE_ACTIVE"},rank=2,title='Chat to active channel',enable=false,data="4357",func='isChatAlert',sound=1},
	{events={"CHAT_MSG_PRIVATE"},rank=10,title='Receive private message',func=nil,sound=2},
	{events={"CHAT_MSG_SERVER"},rank=20,title='Buddy entered the game',func='isBuddyEntered',sound=3},
	{events={"CHAT_MSG_SERVER"},rank=21,title='Buddy left the game',func='isBuddyLeft',sound=4},
	{events={"CHAT_MSG_SERVER"},rank=22,title='Received buddy request',func='isBuddyRequest',sound=5},
	{events={"CHAT_MSG_INCOMINGBUDDYNOTE"},rank=23,title='Received buddy note',func=nil,sound=6},
	{events={"CHAT_MSG_SECTORD"},rank=30,title='Received credits from player',enable=false,func='isReceivedCredits',sound=7},
	--{events={"OUT_OF_AMMO"},rank=110,title='Out of ammo',func=nil,sound=8}, --TODO
	{events={"ENTER_ZONE_NFZ"},rank=200,title='Enter NFZ',enable=false,func=nil,sound=8},
	{events={"LEAVE_ZONE_NFZ"},rank=201,title='Leave NFZ',enable=false,func=nil,sound=9},
	{events={"MISSION_NOTIFICATION"},rank=300,title='Mission updated',func=nil,sound=10},
	{events={"PLAYER_DIED"},rank=100,title='Scored a kill',option_title="NPC kills",option_enable=true,enable=false,func='isScoredKill',sound=11},
	{events={"CHAT_MSG_GUILD"},rank=11,title='Guild chat',func=nil,enable=false,sound=13},
	{events={"CHAT_MSG_GROUP"},rank=12,title='Group chat',--[[option_title="Include notifications messages",option_enable=false,]]enable=false,func='isGroupAlert',sound=13},
	{events={"PLAYER_RECEIVED_NEW_ACCOMPLISHMENTS"},rank=400,title='New Badge',enable=true,func=nil,sound=14},
}

--read saved settings from config file
for key,data_type in pairs(vars.saved_keys) do
	local data = unspickle(gkini.ReadString("SAS", key, string.rep("\"\",", #vars.alerts))) --read data into table, default is empty string
	
	--extract entry from data table and convert format
	for id,alert in ipairs(vars.alerts) do
		if key~='data' or alert.data then --ignore config for key data if data not defined in alerts table
			if data[id]=='' then alert[key] = alert[key] or vars.defaults[key] else alert[key] = vars.conv_keys[data_type](data[id]) end
		end
	end
end

--disable option checkbox for disabled alerts
--for _,alert in ipairs(vars.alerts) do
--	if alert.option_enable then alert.option_enable = alert.enable and "ON" or "OFF" end
--end

--Write all vars data to the config file
function vars.WriteConfig()
	for key,data_type in pairs(vars.saved_keys) do
		local data = {} --table to write
		
		for id,alert in ipairs(vars.alerts) do
			data[id] = data_type=='boolean' and (alert[key] and 1 or 0) or alert[key] or ''
		end
		
		gkini.WriteString("SAS", key, spickle(data))
	end
end

return vars